Method: SpatialFeatures::Download.open

Defined in:
lib/spatial_features/download.rb

.open(file) ⇒ Object

file can be a url, path, or file, any of which can return be a zipped archive



6
7
8
9
10
# File 'lib/spatial_features/download.rb', line 6

def self.open(file)
  file = URI.open(file)
  file = normalize_file(file) if file.is_a?(StringIO)
  return file
end